#
# spec file for package qterminal
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           qterminal
Version:        2.2.1
Release:        1.1
Summary:        A Qt-based terminal emulator
License:        BSD-3-Clause AND GPL-2.0-or-later
URL:            https://github.com/lxqt/qterminal
Source:         %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  c++_compiler
BuildRequires:  cmake >= 3.5.0
BuildRequires:  hicolor-icon-theme
%if 0%{?suse_version} < 1600
BuildRequires:  utempter-devel
%endif
BuildRequires:  cmake(LayerShellQt) >= 6.0.0
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6DBus)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6LinguistTools)
BuildRequires:  cmake(Qt6Test)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(lxqt2-build-tools)
BuildRequires:  cmake(qtermwidget6) >= 2.2.0
Recommends:     %{name}-lang = %{version}-%{release}

%description
The lightweight Qt terminal emulator.

%lang_package

%prep
%autosetup -p1

%build
%cmake_qt6
%{qt6_build}

%install
%{qt6_install}

%find_lang %{name} --with-qt

%check
%ctest

%files
%doc AUTHORS CHANGELOG README.md CONTRIBUTING.md
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/applications/%{name}-drop.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.??g
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/%{name}.metainfo.xml
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/%{name}_bookmarks_example.xml
%license LICENSE

%files lang -f %{name}.lang
%dir %{_datadir}/qterminal
%dir %{_datadir}/qterminal/translations
%if 0%{?sle_version}
%{_datadir}/%{name}/translations/%{name}_???.qm
%endif

%changelog
* Mon May  5 2025 Shawn Dunn <sfalken@opensuse.org>
- Update to version 2.2.1:
  * Removed the workaround for problems that some X11 WMs had with
    the drop-down mode because (1) it prevented exiting on closing
    and (2) didn't let the terminal be focused on showing.
* Thu Apr 17 2025 Shawn Dunn <sfalken@opensuse.org>
- Updated to version 2.2.0:
  * Prompt on closing with a running process
  * Added option for mouse cursor auto-hiding
  * Added option for blinking cursor
  * Added an option for focusing the sub-terminal on mouseover
  * Cleaner preferences dialog
  * Change sizeHint of spacer in Preferences → Behavior
  * Hide/disable some options on Wayland
  * Put the dropdown windown on the active screen under Wayland
  * Added "scope" to the layer window on Wayland
  * Made modal dialogs stay in front of dropdown window on Wayland
  * Put font dialog in front of Preferences dialog on Wayland (and
    draw a border around it)
  * Make font dialog remain in front of Preferences dialog on
    certain X11 WMs
  * Made the dropdown window a tool window under X11
  * Set the dropdown minimum size to 25%%
  * Better wording for the current terminal section in preferences
  * Removed app transparency (terminal transparency exists)
  * Changed "File" to "Session" on the menubar
  * Guarantee that tabs position is between 0-3
  * Removed a wrong style sheet from dropdown mode
  * Ignore presets(subterminal creation) with '-e' option
  * Improved desktop files
  * Fixed shortcuts for switching subterminals with presets
  * Fixed shortcut setting with a profile
- Removed Group: declarations, no longer used
* Thu Jan 16 2025 Thorsten Kukuk <kukuk@suse.com>
- Disable libutempter, it doesn't work anymore with the switch
  from utmp to systemd-logind
* Wed Nov  6 2024 Андрей Алыпов <and.november@opensuse.org>
- Update to version 2.1.0:
  * Pre-release changes (#1177)
  * Weblate commits (#1180)
  * Updated *.ts files (#1179)
  * Weblate commits (#1173)
  * Fixed new tab from preset and context menu's collapse action (#1176)
  * Weblate commits (#1170)
  * Weblate commits (#1168)
  * Weblate commits (#1166)
  * Weblate commits (#1165)
  * Weblate commits (#1164)
* Thu Jun 27 2024 Shawn Dunn <sfalken@opensuse.org>
- Update to 2.0.1:
  * This point release is made mainly because visual artifacts are
    fixed in qtermwidget
  * Single instance for drop-down mode
  * Used layer shell for the drop-down mode under Wayland
  * Prevented a crash on entering 'exit' when bookmark dock is
    shown.
  * Fixed the window height in drop-down mode
  * Set `QTERMWIDGET_MINIMUM_VERSION`, which was missing after Qt6
    Port
* Sat May 18 2024 Андрей Алыпов <and.november@opensuse.org>
- Update to 2.0.0:
  * Ported to Qt6.
  * Some fixes are made and the code is cleaned up.
* Wed Jan  3 2024 Andreas Stieger <andreas.stieger@gmx.de>
- fix Tumbleweed build (ownership of /usr/share/icons/hicolor/64x64)
- fix license (bundled libqxt is BSD)
- remove unneeded binaries
- run tests
* Mon Nov  6 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 1.4.0:
  * Handled bell (BEL, '\a') via libcanberra, and added an "Audible
    bell" option.
  * Supported Putty-style mouse button swap
  * Corrected tab order in settings dialog.
  * A great amount of code cleanup.
* Sat Apr 15 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 1.3.0:
  * Guaranteed correct positioning of the context menu under
    Wayland.
  * Fixed a crash in the dropdown mode under Wayland.
  * Improved UX by opening new terminals in current directory by
    default.
  * Corrected typos and the meta-info license.
* Sat Nov  5 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- Update to 1.2.0:
  * Add CI using GitHub Actions.
  * Fixed command parsing with the `-e` option.
  * Avoid segfault when using global menus.
  * Improved documentation for the `--profile` option.
* Wed May  4 2022 Michael Vetter <mvetter@suse.com>
- Update 1.1.0:
  * The bookmark functionality is improved a lot. An example
    bookmarks file is also added.
  * Several (old) issues in the drop-down mode are fixed.
  * A shortcut entry is added for the drop-down shortcut.
  * Problems in closing of the last tab with prompt are fixed.
  * Fixed updating of shortcuts on tab switching/removal/creation.
  * Fixed right clicking of an empty area of tabbar.
  * Now selecting an unlimited history in Terminal settings
    disables the history size spin-box.
* Mon Nov  8 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.0.0:
  * Bumped minimum required Qt version to 5.15.
  * Respect preset splitting on opening new window and double clicking tab-bar.
  * Trim shell strings.
  * Added an option for keeping drop-down window open.
  * Added a workaround for wrong menu positions under Wayland.
* Fri Apr 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.17.0:
  * Made "Action after paste" clearer and default to "Scrolling to bottom".
  * Added an option to disable bracketed paste mode.
  * Added modes for background image.
  * Removed two warnings that were shown when QTerminal was started.
* Sun Nov 15 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.16.1:
  * Fixed a regression in the layout of Terminal settings dialog.
  * Fixed translation of shortcuts (in Terminal settings dialog).
* Wed Nov  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.16.0:
  * Made closing of tab on middle-clicking optional.
  * Avoid loop variable copy.
  * Emit signals with Q_EMIT.
  * Use the default constructor of QFlags.
  * Dropped qmake .pro file.
  * Made the color scheme dirs comply with XDG Base Directory Specification.
  * Added an optopn for openning the new tab to the right of the active tab.
  * Added virtual destructor to a base class.
  * Let QStandardPaths::locateAll() handle application name.
  * Put drop-down QTerminal on screen with cursor.
* Wed Jun 24 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Don't package filesystem dirs
* Mon Apr 27 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Changed qterminal.keyring to tsujan's key
* Sat Apr 25 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 0.15.0
  * A scrollable and compact Settings dialog.
  * Added actions for switching to tab by index.
  * Allowed to disable drawing line characters.
  * Allowed a fixed custom size for QTerminal.
  * Made the menubar accelerators optional.
  * Added "Hide Window Borders" to context menu and added an option for borderless state.
  * Implemented an action that allows you to send the history to your editor.
  * Fixes for macOS.
  * Several fixes.
* Fri Mar  1 2019 mvetter@suse.com
- Update to 0.14.1:
  * Only translations was changed
* Thu Jan 31 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.14.0:
  * Added terminal margins
  * Added history-based tab switching
  * Smaller settings dialog
  * Prevent TAB from changing focus in the shortcut editor
  * Remember the maximization state of the window
- Move translation from lxqt-l10n into package
* Sat Jun 23 2018 mvetter@suse.com
- Remove BuildRequires lxqt-l10n
* Tue May 22 2018 mvetter@suse.com
- Update to 0.9.0:
  * Fix tab texts, especially for vertical tabs
  * Sort color schemes alphabetically
  * Support modifying $TERM and use xterm-256color by default
  * Misc bug fixes for the tabbar
  * Close tab on middle clicking
  * A real shortcut editor
  * Allow to change tab title color
  * Make tab closing button configurable
  * Make active tab text bold to make it more visible
  * New config: show terminal size on resize
  * Fix bracket paste
  * Fix terminal menubar transparency
  * Add option for configuring tab width limit.
  * Add maximum tab width and proper text eliding.
  * Enable bidi by default
  * Add RTL support button
* Wed Oct 25 2017 mvetter@suse.com
- Update to 0.8.0:
  * Set version to 0.8.0
  * Update information on distribution package
  * Added legacy font setting support
  * Made font in settings file human readable
  * Fix action inconsistency when switching tabs
  * Lithuanian translation
  * Added Lithuanian language
  * Don't export github templates
  * correct spelling mistake
  * Adapt to QTermWidget API changes after DECSCUSR handling
  * liblxqt dont make sense here
  * Copied issue template
  * Drops Qt5Core_VERSION_STRING
  * Update qterminal_drop.desktop
  * Update qterminal.desktop
  * Make disabled actions consistent at all times (#331)
  * DBus DropMode (#325)
  * Change subterminal shortcuts to avoid breaking qtermwidget scrolling (#327)
  * Update main.cpp (#322)
  * Fix toggle menu action.
  * Focus highlight (#266)
  * Replace numbered terminals with directional navigation (#255)
  * Fix '1 Terminal' preset (#324)
  * Change "Clear Current Tab" into "Clear Active Terminal" (#268)
  * Fix duplicated items, rework MainWindow memory-management (#313)
  * Fixed comment - needless compiler warnings are annoying (#321)
  * DBus integration (#307)
  * Restore filter actions (#310)
  * New features: trim \n from pasted strings, confirm multiline pastes (#309)
  * Support custom QSS styles
  * Call QApp destructor (#306)
  * Fixes (#318)
  * Refactor dangling actions, delete windows on close
  * Adds superbuild support
  * Improve translation (.ts) handling
  * Removes Qt5X11Extras_DEFINITIONS
  * Stops adding not exist entries to CMAKE_MODULE_PATH
  * Use the LXQtCompilerSettings module
  * Adapt to QTermWidget improved CMake
  * Fix a copy/paste error from 4afcc4d0d0922f526f89aadf16ec0517f6b5267e
  * Update dependencies and cleanup trailing spaces
- Remove post and postun
- Add BuildRequires utf8proc-devel for better utf8 support
- Add BuildRequires pkgconfig(Qt5DBus) for new dbus interface
* Sun Feb 26 2017 sfalken@opensuse.org
- Update to 0.7.1:
  * Bump patch version (#294)
  * Add common shortcuts for switching tabs (#275)
  * Fix tabstop order in properties dialog & add buddy relations for labels. (#290)
  * Add preferences for background images (#273)
  * Disable menu actions that are not applicable currently (#244)
  * DEFINES += STR_VERSION=\\\"0.7.0\\\"
  * Add context menu actions for URLs and E-Mail addresses (#276)
  * Removed minimum size (#265)
  * Set maxval of dropdown spinboxen to 100, instead of 99
  * Use the new lxqt-build-tools package
  * Fix context menu actions being applied to the window opened last (#235)
  * Show exit confirmation dialog when closing the last window tab (#242)
  * remove "building with cpack" from CMakeLists.txt - not used anymore Added very basic .gitattributes
* Sun Sep 25 2016 mvetter@suse.com
- Update to 0.7.0:
  * Bump version to 0.7.0 (#262)
  * Update README.md
  * Collapse splitter hierarchies containing a single terminal (#254)
  * Make qterminal.appdata.xml valid (#257)
  * Add config option for changing window's title/icon
  * Add support for automatic title & icon modification
  * Delete Properties instance on exit (#239)
  * Fix compilation warning related to QXmlStreamReader (#247)
  * Set the desktopFileName property
  * Fix typo in the conditional expression
  * Add location for custom color schemes (#234)
  * CMake Support changes (#237)
  * Add keyboard cursor shape setting (#228)
  * made the .pro file work on openSUSE; #229 (#232)
  * Fix renaming a tab from the menu
  * Make the rename current session shortcut work and configurable
  * build: Use external translations
  * ts-files removal (#222)
  * Add pt_BR (Brazilian Portuguese) translation (#215)
  * Merge pull request #214 from f2404/212_collapse_segfault_fix
  * Remove noisy qDebug()
  * Fix jumbled prompt
  * Add Greek (el) translation
  * Missing equal symbol for xml template
  * Delete MainWindow on exit
  * Link to the current github projects and trackers
  * Apply context menu to the tab that it was opened over
  * Close tabs in reverse order
  * Eliminate memory leaks by closing tabs on exit
  * Russian translation update
  * Fix menubar transparency
  * Fix default settings width
  * Fix bookmarks widget transparency
  * Use the same icon for dropdown and regular terminal
  * Fix license file
  * Improve README and use markdown
  * Fixed button focus in close confirmation (resolves #179).
  * Updated german translation.
  * Fix Simplified Chinese(zh_CN)
  * Update japanese translation
  * Add Japanese translation to *.desktop
  * fixed #174 XDG_CONFIG_DIRS support - read system wide QSettings
  * Fix license issues within qterminal
  * Add chinese translation
  * Require Qt 5.2 or higher
  * fix private header dependency for X11 global shortcuts
  * fix searching for Qt5 private headers
  * make only terminal widget transparent, not the parent window
  * Fix japanese translation
  * Russian translation update
  * Add Japanese translation
  * fixed #160 FTBFS as of commit 4967123
  * Fixes for Portuguese language
  * Fixes missing App Window icon
  * Hungarian translation added
  * Update qterminal_tr.ts
  * Create qterminal_tr.ts
  * do not overwrite settings in migrateSettings
  * remove fullscreen patch
  * migrateSettings add size and pos and rm geometry
  * split geometry into size and position
  * define saveGeomOnExit in properties.h
  * add save geometry on exit
  * Add Alt-<letter> shortcuts to all menu items.
  * Make sure no settings are overwritten in migrateSettings().
  * Update index property of tabs when tabs are moved by drag-and-drop.
  * Update german translation.
  * Corrected terminology in settings (transparency vs. opacity). Now transparency instead of opacity is used in the whole application consistently.
  * Migrate AlwaysShowTabs-setting.
  * Move migrateSettings()-method to Properties-class and call it *before* loadSettings().
  * Update version number in settings.
  * Renamed always show tabs setting.
  * Portuguese update
  * Add instructions to disable system qxt when building with Qt5.
  * Changed position of font button in settings.
  * Changed layout of font-setting to better fit to the other settings in the widget.
  * Appdata file for QTerminal (resolves #60).
  * Add view-menu actions to mainwindow, to make them available when menu bar is hidden.
  * Add fullscreen mode.
  * Ignore user-specific project files of QtCreator.
  * Resolves #115: Store Actions of 'View'-menu in properties too and enable shorctus for them.
  * Set shortcuts for 'Preferences...' and 'Quit' from settings on startup.
  * Fixed #83: Add menu actions to main window.
  * Fixed #93: Add 'Toggle Menu' and 'Preferences...' to context menu.
  * Use GNUInstallDirs in CMakeLists.txt to stop hardcoding paths
  * Make the left column expandable to get more space for translated text.
  * Updated german translation
  * Remove empty file
  * Remove unnecessarily noisy qDebug calls
  * Portuguese update
  * Add Portuguese translation
  * Update Russian translation
  * slightly naive "layout/preset" implementation
  * fixed build for Qt4 and Qt5.x < 5.2
  * Rework settings window
  * Fixed translation (added tr() for some combo boxes in properties dialog).
- Add keyring
- Remove preferences_context_menu.patch: upstreamed
* Mon Aug  8 2016 mvetter@suse.com
- Adapt qtermwidget name change
  See: https://build.opensuse.org/request/show/397609
* Tue Mar  8 2016 mvetter@suse.com
- Adding: preferences_context_menu.patch
  Without this it's possible to disable the menu bar with
  no way to bring it back.
* Sat Mar  5 2016 avvissu@yandex.ru
- Initial release
